@@ -5,13 +5,13 @@ import logging
 import os
 import sys
 import time
+import traceback
 from difflib import unified_diff
 from typing import Collection, List, Optional, Tuple
 
 import astor
 
-from flynt.cli_messages import farewell_message
-from flynt.process import (
+from flynt.code_editor import (
     fstringify_code_by_line,
     fstringify_concats,
     fstringify_static_joins,
@@ -47,7 +47,7 @@ def _fstringify_file(
             log.error(f"Exception while reading {filename}", exc_info=True)
             return None
 
-    result = fstringify_content(
+    result = fstringify_code(
         contents=contents,
         state=state,
         filename=filename,
@@ -74,11 +74,12 @@ def _fstringify_file(
     return result
 
 
-def fstringify_content(
+def fstringify_code(
     contents: str,
     state: State,
     filename: str = "<code>",
 ) -> Optional[FstringifyResult]:
+    """transform given string, assuming it's python code."""
     try:
         ast_before = ast.parse(contents)
     except SyntaxError:
@@ -94,19 +95,31 @@ def fstringify_content(
                 state=state,
             )
         if state.transform_concat:
-            new_code, concat_changes = fstringify_concats(
-                new_code,
-                state=state,
-            )
-            changes += concat_changes
-            state.concat_changes += concat_changes
+            try:
+                new_code, concat_changes = fstringify_concats(
+                    new_code,
+                    state=state,
+                )
+            except Exception:
+                msg = traceback.format_exc()
+                log.error("Transforming concatenation of literal strings failed")
+                log.error(msg)
+            else:
+                changes += concat_changes
+                state.concat_changes += concat_changes
         if state.transform_join:
-            new_code, join_changes = fstringify_static_joins(
-                new_code,
-                state=state,
-            )
-            changes += join_changes
-            state.join_changes += join_changes
+            try:
+                new_code, join_changes = fstringify_static_joins(
+                    new_code,
+                    state=state,
+                )
+            except Exception:
+                msg = traceback.format_exc()
+                log.error("Transforming concatenation of literal strings failed")
+                log.error(msg)
+            else:
+                changes += join_changes
+                state.join_changes += join_changes
 
     except Exception as e:
         msg = str(e) or e.__class__.__name__
@@ -148,6 +161,7 @@ def fstringify_files(
     files: List[str],
     state: State,
 ) -> int:
+    """apply transforms to sequence of files, keep shared stats."""
     changed_files = 0
     total_charcount_original = 0
     total_charcount_new = 0
@@ -184,6 +198,13 @@ def fstringify_files(
     return changed_files
 
 
+farewell_message = (
+    "Please run your tests before committing. Did flynt get a perfect conversion? give it a star at: "
+    "\n~ https://github.com/ikamensh/flynt ~"
+    "\nThank you for using flynt. Upgrade more projects and recommend it to your colleagues!\n"
+)
+
+
 def _print_report(
     state: State,
     found_files: int,
