@@ -1,9 +1,10 @@
 import ast
 from typing import Tuple
 
+from flynt.candidates.ast_call_candidates import is_call_format
 from flynt.linting.fstr_lint import FstrInliner
 from flynt.state import State
-from flynt.transform.format_call_transforms import joined_string, matching_call
+from flynt.transform.format_call_transforms import joined_string
 from flynt.transform.percent_transformer import is_percent_stringify, transform_binop
 
 
@@ -15,24 +16,22 @@ class FstringifyTransformer(ast.NodeTransformer):
         super().__init__()
         self.state = state
         self.counter = 0
-        self.string_in_string = False
 
     def visit_Call(self, node: ast.Call) -> ast.AST:
         """
         Convert `ast.Call` to `ast.JoinedStr` f-string.
         """
-        if self.state.transform_format and matching_call(node):
+        if self.state.transform_format and is_call_format(node):
             self.state.call_candidates += 1
 
             # bail in these edge cases...
             if any(isinstance(arg, ast.Starred) for arg in node.args):
                 return node
 
-            result_node, str_in_str = joined_string(
+            result_node = joined_string(
                 node,
                 aggressive=self.state.aggressive,
             )
-            self.string_in_string = str_in_str
             self.visit(result_node)
             self.counter += 1
             self.state.call_transforms += 1
@@ -70,11 +69,10 @@ class FstringifyTransformer(ast.NodeTransformer):
                 ):
                     return node
 
-            result_node, str_in_str = transform_binop(
+            result_node = transform_binop(
                 node,
                 aggressive=self.state.aggressive,
             )
-            self.string_in_string = str_in_str
             self.counter += 1
             self.state.percent_transforms += 1
             return result_node
@@ -85,10 +83,10 @@ class FstringifyTransformer(ast.NodeTransformer):
 def fstringify_node(
     node: ast.AST,
     state: State,
-) -> Tuple[ast.AST, bool, bool]:
+) -> Tuple[ast.AST, bool]:
     ft = FstringifyTransformer(state)
     result = ft.visit(node)
     il = FstrInliner()
     il.visit(result)
 
-    return result, ft.counter > 0, ft.string_in_string
+    return result, ft.counter > 0
